@@ -49,7 +49,7 @@ extern crate pest_derive;
 
 #[cfg(test)]
 #[macro_use]
-extern crate spectral;
+extern crate speculoos;
 
 use pest::Parser;
 
@@ -150,7 +150,7 @@ pub fn parse_body(body: &str) -> Result<Option<String>, ParseError> {
         .next()
         .unwrap();
 
-    let body = pair.as_str();
+    let body = pair.as_str().trim();
     if !body.is_empty() {
         Ok(Some(body.to_string()))
     } else {
